@@ -1,7 +1,7 @@
 /*
    cfg.c - all the configurable options in cvsd
 
-   Copyright (C) 2003 Arthur de Jong.
+   Copyright (C) 2003, 2004 Arthur de Jong.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -37,6 +37,7 @@
 #include "log.h"
 
 
+/* note: if you change this, be sure to also change CVSUMASK_IDX in cfg.h */
 static char *default_environment[] = {
   "HOME=/",
   "PATH=/bin",
@@ -60,6 +61,9 @@ struct cvsd_cfg *cfg_new()
   cfg->gid        = NOGID;
   cfg->nice       = 0;
   cfg->umask      = 0027;
+#ifdef USE_CAPABILITIES
+  cfg->capabilities = NULL;
+#endif /* USE_CAPABILITIES */
   cfg->addresses  = NULL;
   cfg->maxconnections = 0;
   cfg->cvscmd     = NULL; /* default is set according to configured rootjail */
