@@ -14,7 +14,7 @@
 
    Copyright (C) 1999 Chris Black.
    Copyright (C) 2000 Philippe Kehl.
-   Copyright (C) 2001, 2002, 2003, 2004 Arthur de Jong.
+   Copyright (C) 2001, 2002, 2003, 2004, 2005 Arthur de Jong.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -93,10 +93,6 @@
 extern char **environ;
 
 
-/* the name by which this program was run. */
-static char *program_name;
-
-
 /* the number of children spawned */
 static volatile int cvsd_numchildren=0;
 
@@ -127,14 +123,15 @@ static void display_version(FILE *fp)
 {
   fprintf(fp,"%s\n",PACKAGE_STRING);
   fprintf(fp,"Written by Chris Black, Philippe Kehl and Arthur de Jong.\n\n");
-  fprintf(fp,"Copyright (C) 1999,2000,2004 Chris Black, Philippe Kehl and Arthur de Jong.\n"
+  fprintf(fp,"Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005 Chris Black,\n"
+             "Philippe Kehl and Arthur de Jong.\n"
              "This is free software; see the source for copying conditions.  There is NO\n"
              "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n");
 }
 
 
 /* display usage information to stdout and exit(status) */
-static void display_usage(FILE *fp)
+static void display_usage(FILE *fp, char *program_name)
 {
   fprintf(fp,"Usage: %s [OPTION]...\n",program_name);
   fprintf(fp,"chroot wrapper to run `cvs pserver' more securely.\n");
@@ -171,7 +168,7 @@ static void parse_cmdline(int argc,char *argv[],struct cvsd_cfg *cfg)
       if (optarg[0]!='/')
       {
         fprintf(stderr,"%s: configfile '%s' must be an absolute path\n",
-                program_name,optarg);
+                argv[0],optarg);
         exit(1);
       }
       cfg->configfile=xstrdup(optarg);
@@ -181,7 +178,7 @@ static void parse_cmdline(int argc,char *argv[],struct cvsd_cfg *cfg)
       log_setdefaultloglevel(LOG_DEBUG);
       break;
     case 'h': /*     --help         display this help and exit */
-      display_usage(stdout);
+      display_usage(stdout,argv[0]);
       exit(0);
     case 'V': /*     --version      output version information and exit */
       display_version(stdout);
@@ -190,7 +187,7 @@ static void parse_cmdline(int argc,char *argv[],struct cvsd_cfg *cfg)
     case '?': /* unknown option character or extraneous parameter */
     default:
       fprintf(stderr,"Try `%s --help' for more information.\n",
-              program_name);
+              argv[0]);
       exit(1);
     }
   }
@@ -198,9 +195,9 @@ static void parse_cmdline(int argc,char *argv[],struct cvsd_cfg *cfg)
   if (optind<argc)
   {
     fprintf(stderr,"%s: unrecognized option `%s'\n",
-            program_name,argv[optind]);
+            argv[0],argv[optind]);
     fprintf(stderr,"Try `%s --help' for more information.\n",
-            program_name);
+            argv[0]);
     exit(1);
   }
 }
@@ -671,9 +668,6 @@ int main(int argc,char *argv[])
   cap_t caps;
 #endif /* USE_CAPABILITIES */
 
-  /* save program name */
-  program_name=argv[0];
-
   /* load the default configuration */
   cfg=cfg_new();
 
